pub struct StreamingExtractor<'m, M: Model> { /* private fields */ }Expand description
A streaming entity extractor that processes text in chunks.
Implementations
Sourceimpl<'m, M: Model> StreamingExtractor<'m, M>
impl<'m, M: Model> StreamingExtractor<'m, M>
Sourcepub fn new(model: &'m M, config: ChunkConfig) -> Self
pub fn new(model: &'m M, config: ChunkConfig) -> Self
Create a new streaming extractor with the given model and config.
Sourcepub fn with_model(model: &'m M) -> Self
pub fn with_model(model: &'m M) -> Self
Create with default config.
Sourcepub fn extract<'t>(&'m self, text: &'t str) -> EntityIterator<'m, 't, M> ⓘ
pub fn extract<'t>(&'m self, text: &'t str) -> EntityIterator<'m, 't, M> ⓘ
Extract entities from text, yielding them as an iterator.