pub enum Gender {
Masculine,
Feminine,
Neutral,
Unknown,
}Expand description
Gender classification for NLP tasks.
Used for pronoun resolution, coreference clustering, and bias analysis.
Examples
ⓘ
use anno_core::types::Gender;
let gender = Gender::from_pronoun("she");
assert_eq!(gender, Some(Gender::Feminine));
let gender = Gender::from_pronoun("they");
assert_eq!(gender, Some(Gender::Neutral));Variants
Masculine
Masculine (he/him/his)
Feminine
Feminine (she/her/hers)
Neutral
Neutral or non-binary (they/them/theirs, it/its)
Unknown
Unknown or unspecified
Implementations
Sourceimpl Gender
impl Gender
Sourcepub fn from_pronoun(pronoun: &str) -> Option<Gender>
pub fn from_pronoun(pronoun: &str) -> Option<Gender>
Infer gender from a pronoun.
Returns None for non-pronoun inputs.
Examples
ⓘ
use anno_core::types::Gender;
assert_eq!(Gender::from_pronoun("he"), Some(Gender::Masculine));
assert_eq!(Gender::from_pronoun("She"), Some(Gender::Feminine));
assert_eq!(Gender::from_pronoun("they"), Some(Gender::Neutral));
assert_eq!(Gender::from_pronoun("it"), Some(Gender::Neutral));
assert_eq!(Gender::from_pronoun("John"), None);Sourcepub fn subject_pronoun(&self) -> &'static str
pub fn subject_pronoun(&self) -> &'static str
Get typical subject pronoun for this gender.
Sourcepub fn object_pronoun(&self) -> &'static str
pub fn object_pronoun(&self) -> &'static str
Get typical object pronoun for this gender.
Sourcepub fn possessive_pronoun(&self) -> &'static str
pub fn possessive_pronoun(&self) -> &'static str
Get typical possessive pronoun for this gender.
Sourcepub fn is_compatible(&self, other: &Gender) -> bool
pub fn is_compatible(&self, other: &Gender) -> bool
Check if this gender is compatible with another for coreference.
Unknown is compatible with everything. Neutral is compatible with everything (singular they can refer to any gender).