pub struct CorefLinkFactor {
pub mention_i: usize,
pub mention_j: usize,
pub weights: CorefLinkWeights,
/* private fields */
}Expand description
Factor coupling coreference and entity linking.
Encourages coreferent mentions to link to related Wikipedia articles. Only fires when mention i is linked to mention j (a_i = j).
Features
- Same title: e_i = e_j (same article)
- Shared outlinks: articles share outgoing links
- Mutual links: one article links to the other
Example
If “the company” → “Dell” is a coref link:
- e(“Dell”) = Dell (company article)
- e(“the company”) = Dell (should link to same)
- Factor: high score for same entity
Fields
mention_i: usizeCurrent mention index (i)
mention_j: usizeAntecedent mention index (j)
weights: CorefLinkWeightsWeights
Implementations
Sourceimpl CorefLinkFactor
impl CorefLinkFactor
Sourcepub fn new(
mention_i: usize,
mention_j: usize,
weights: CorefLinkWeights,
) -> Self
pub fn new( mention_i: usize, mention_j: usize, weights: CorefLinkWeights, ) -> Self
Create a new Coref+Link factor.
Sourcepub fn with_knowledge(self, knowledge: Arc<WikipediaKnowledgeStore>) -> Self
pub fn with_knowledge(self, knowledge: Arc<WikipediaKnowledgeStore>) -> Self
Set knowledge store.