pub struct AutoNER { /* private fields */ }Expand description
Automatic model selection - routes to the default model.
AutoNER is simply an alias for the default model (StackedNER). It does NOT combine multiple models - it just picks one default method. This avoids mixing and matching scores from different models.
Implementations