#[non_exhaustive]pub enum Task {
Show 13 variants
NER,
IntraDocCoref,
InterDocCoref,
NED,
RelationExtraction,
EventExtraction,
DiscontinuousNER,
VisualNER,
TemporalNER,
AspectExtraction,
SlotFilling,
POS,
DependencyParsing,
}Expand description
The primary NLP task a dataset is designed for.
A dataset may support multiple tasks (e.g., NER + Entity Linking), but has one primary task that determines its structure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NER
Named Entity Recognition (sequence labeling)
IntraDocCoref
Intra-document coreference resolution
InterDocCoref
Inter-document (cross-document) coreference resolution
NED
Named Entity Disambiguation / Entity Linking to KB
RelationExtraction
Relation Extraction between entities
EventExtraction
Event extraction and argument role labeling
DiscontinuousNER
Discontinuous/nested NER (e.g., CADEC, ShARe)
VisualNER
Visual document NER (forms, receipts, etc.)
TemporalNER
Temporal NER (diachronic entities, time expressions)
AspectExtraction
Sentiment/opinion target extraction
SlotFilling
Slot filling for dialogue systems
POS
Part-of-speech tagging (often bundled with NER)
DependencyParsing
Dependency parsing
Implementations
Sourceimpl Task
impl Task
Sourcepub const fn produces_entities(&self) -> bool
pub const fn produces_entities(&self) -> bool
Returns true if this task produces entity spans.
Sourcepub const fn involves_coreference(&self) -> bool
pub const fn involves_coreference(&self) -> bool
Returns true if this task involves coreference chains.
Sourcepub const fn involves_kb_linking(&self) -> bool
pub const fn involves_kb_linking(&self) -> bool
Returns true if this task links to external knowledge bases.
Sourcepub const fn involves_relations(&self) -> bool
pub const fn involves_relations(&self) -> bool
Returns true if this task extracts relations between entities.