pub struct TextSpan {
pub byte_start: usize,
pub byte_end: usize,
pub char_start: usize,
pub char_end: usize,
}Expand description
A text span with both byte and character offsets.
This is the canonical representation for entity positions. Store both to avoid repeated conversion.
Fields
byte_start: usizeByte offset (start, inclusive)
byte_end: usizeByte offset (end, exclusive)
char_start: usizeCharacter offset (start, inclusive)
char_end: usizeCharacter offset (end, exclusive)
Implementations
Sourceimpl TextSpan
impl TextSpan
Sourcepub fn from_bytes(text: &str, byte_start: usize, byte_end: usize) -> Self
pub fn from_bytes(text: &str, byte_start: usize, byte_end: usize) -> Self
Create a span from byte offsets, computing char offsets from text.
Arguments
text- The full text (needed to compute char offsets)byte_start- Byte offset start (inclusive)byte_end- Byte offset end (exclusive)
Example
use anno::offset::TextSpan;
let text = "Price €50";
// "Price " = 6 bytes, € = 3 bytes, "50" = 2 bytes = 11 total
let span = TextSpan::from_bytes(text, 6, 11); // "€50"
assert_eq!(span.char_start, 6);
assert_eq!(span.char_end, 9); // € is 1 char but 3 bytesSourcepub fn from_chars(text: &str, char_start: usize, char_end: usize) -> Self
pub fn from_chars(text: &str, char_start: usize, char_end: usize) -> Self
Create a span from character offsets, computing byte offsets from text.
Arguments
text- The full text (needed to compute byte offsets)char_start- Character offset start (inclusive)char_end- Character offset end (exclusive)
Sourcepub const fn ascii(start: usize, end: usize) -> Self
pub const fn ascii(start: usize, end: usize) -> Self
Create a span for ASCII text where byte == char offsets.
This is a fast path for ASCII-only text.
Sourcepub const fn byte_range(&self) -> Range<usize>
pub const fn byte_range(&self) -> Range<usize>
Get byte range.
Sourcepub const fn char_range(&self) -> Range<usize>
pub const fn char_range(&self) -> Range<usize>
Get character range.